==> encommon-0.11.0-py3-none-any.whl: encommon/times/test/test_timers.py <==
"""
Functions and routines associated with Enasis Network Common Library.

This file is part of Enasis Network software eco-system. Distribution
is permitted, for more information consult the project license file.
"""



from pathlib import Path
from typing import Any

from pytest import fixture
from pytest import raises

from ..params import TimerParams
from ..params import TimersParams
from ..timers import Timers
from ..times import Times
from ...types import inrepr
from ...types import instr



@fixture
def timers(
    tmp_path: Path,
) -> Timers:
    """
    Construct the instance for use in the downstream tests.

    :param tmp_path: pytest object for temporal filesystem.
    :returns: Newly constructed instance of related class.
    """

    source: dict[str, Any] = {
        'one': {'timer': 1},
        'two': {'timer': 1}}

    params = TimersParams(
        timers=source)

    timers = Timers(
        params,
        file=f'{tmp_path}/cache.db')

    sqlite = timers.sqlite

    sqlite.execute(
        """
        insert into timers
        ("group", "unique",
         "update")
        values (
         "default", "two",
         "1970-01-01T00:00:00Z")
        """)  # noqa: LIT003

    sqlite.execute(
        """
        insert into timers
        ("group", "unique",
         "update")
        values (
         "default", "tre",
         "1970-01-01T00:00:00Z")
        """)  # noqa: LIT003

    sqlite.commit()

    timers.load_children()

    return timers



def test_Timers(
    timers: Timers,
) -> None:
    """
    Perform various tests associated with relevant routines.

    :param timers: Primary class instance for timers object.
    """


    attrs = list(timers.__dict__)

    assert attrs == [
        '_Timers__params',
        '_Timers__sqlite',
        '_Timers__file',
        '_Timers__table',
        '_Timers__group',
        '_Timers__timers']


    assert inrepr(
        'timers.Timers object',
        timers)

    assert hash(timers) > 0

    assert instr(
        'timers.Timers object',
        timers)


    assert timers.params is not None

    assert timers.sqlite is not None

    assert timers.file[-8:] == 'cache.db'

    assert timers.table == 'timers'

    assert timers.group == 'default'

    assert len(timers.children) == 2


    timer = timers.children['one']

    assert timer.times >= Times('-1s')


    timer = timers.children['two']

    assert timer.times == '1970-01-01'



def test_Timers_cover(
    timers: Timers,
) -> None:
    """
    Perform various tests associated with relevant routines.

    :param timers: Primary class instance for timers object.
    """


    assert not timers.ready('one')

    assert timers.ready('two')


    timers.update('two', 'now')

    assert not timers.ready('two')

    timers.load_children()

    assert timers.ready('two')


    timers.update('two', 'now')

    assert not timers.ready('two')

    timers.save_children()
    timers.load_children()

    assert not timers.ready('two')


    params = TimerParams(
        timer=1,
        start='-1s')

    timers.create('fur', params)

    assert timers.ready('fur')

    timers.delete('fur')



def test_Timers_raises(
    timers: Timers,
) -> None:
    """
    Perform various tests associated with relevant routines.

    :param timers: Primary class instance for timers object.
    """


    _raises = raises(ValueError)

    with _raises as reason:
        timers.ready('dne')

    _reason = str(reason.value)

    assert _reason == 'unique'


    _raises = raises(ValueError)

    params = TimerParams(timer=1)

    with _raises as reason:
        timers.create('one', params)

    _reason = str(reason.value)

    assert _reason == 'unique'


    _raises = raises(ValueError)

    with _raises as reason:
        timers.update('dne', 'now')

    _reason = str(reason.value)

    assert _reason == 'unique'


    _raises = raises(ValueError)

    with _raises as reason:
        timers.delete('dne')

    _reason = str(reason.value)

    assert _reason == 'unique'

==> encommon-0.11.1-py3-none-any.whl: encommon/times/test/test_timers.py <==
"""
Functions and routines associated with Enasis Network Common Library.

This file is part of Enasis Network software eco-system. Distribution
is permitted, for more information consult the project license file.
"""



from pathlib import Path
from time import sleep
from typing import Any

from pytest import fixture
from pytest import raises

from ..params import TimerParams
from ..params import TimersParams
from ..timers import Timers
from ..times import Times
from ...types import inrepr
from ...types import instr



@fixture
def timers(
    tmp_path: Path,
) -> Timers:
    """
    Construct the instance for use in the downstream tests.

    :param tmp_path: pytest object for temporal filesystem.
    :returns: Newly constructed instance of related class.
    """

    source: dict[str, Any] = {
        'one': {'timer': 1},
        'two': {'timer': 1}}

    params = TimersParams(
        timers=source)

    timers = Timers(
        params,
        file=f'{tmp_path}/cache.db')

    sqlite = timers.sqlite

    sqlite.execute(
        """
        insert into timers
        ("group", "unique",
         "update")
        values (
         "default", "two",
         "1970-01-01T00:00:00Z")
        """)  # noqa: LIT003

    sqlite.execute(
        """
        insert into timers
        ("group", "unique",
         "update")
        values (
         "default", "tre",
         "1970-01-01T00:00:00Z")
        """)  # noqa: LIT003

    sqlite.commit()

    timers.load_children()

    return timers



def test_Timers(
    timers: Timers,
) -> None:
    """
    Perform various tests associated with relevant routines.

    :param timers: Primary class instance for timers object.
    """


    attrs = list(timers.__dict__)

    assert attrs == [
        '_Timers__params',
        '_Timers__sqlite',
        '_Timers__file',
        '_Timers__table',
        '_Timers__group',
        '_Timers__timers']


    assert inrepr(
        'timers.Timers object',
        timers)

    assert hash(timers) > 0

    assert instr(
        'timers.Timers object',
        timers)


    assert timers.params is not None

    assert timers.sqlite is not None

    assert timers.file[-8:] == 'cache.db'

    assert timers.table == 'timers'

    assert timers.group == 'default'

    assert len(timers.children) == 2


    timer = timers.children['one']

    assert timer.times >= Times('-1s')


    timer = timers.children['two']

    assert timer.times == '1970-01-01'



def test_Timers_cover(
    timers: Timers,
) -> None:
    """
    Perform various tests associated with relevant routines.

    :param timers: Primary class instance for timers object.
    """


    assert timers.ready('two')

    timers.update('two', 'now')

    assert not timers.ready('two')


    timers = Timers()


    params = TimerParams(timer=1)

    timers.create('fur', params)

    assert not timers.ready('fur')

    sleep(1)

    assert timers.ready('fur')

    timers.delete('fur')



def test_Timers_raises(
    timers: Timers,
) -> None:
    """
    Perform various tests associated with relevant routines.

    :param timers: Primary class instance for timers object.
    """


    _raises = raises(ValueError)

    with _raises as reason:
        timers.ready('dne')

    _reason = str(reason.value)

    assert _reason == 'unique'


    _raises = raises(ValueError)

    params = TimerParams(timer=1)

    with _raises as reason:
        timers.create('one', params)

    _reason = str(reason.value)

    assert _reason == 'unique'


    _raises = raises(ValueError)

    with _raises as reason:
        timers.update('dne', 'now')

    _reason = str(reason.value)

    assert _reason == 'unique'


    _raises = raises(ValueError)

    with _raises as reason:
        timers.delete('dne')

    _reason = str(reason.value)

    assert _reason == 'unique'
